==> apache-seata-2.4.0-incubating-src.tar.gz: apache-seata-2.4.0-incubating-src/sqlparser/seata-sqlparser-core/src/test/java/org/apache/seata/sqlparser/EscapeSymbolTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.sqlparser;

import org.junit.jupiter.api.Test;
import static org.junit.jupiter.api.Assertions.assertEquals;

public class EscapeSymbolTest {

    @Test
    public void testGetLeftSymbol() {
        char expectedLeftSymbol = '"';
        EscapeSymbol escapeSymbol = new EscapeSymbol(expectedLeftSymbol, '"');
        assertEquals(expectedLeftSymbol, escapeSymbol.getLeftSymbol(),
                "The left symbol should be '" + expectedLeftSymbol + "'");
    }

    @Test
    public void testGetRightSymbol() {
        char expectedRightSymbol = '"';
        EscapeSymbol escapeSymbol = new EscapeSymbol('"', expectedRightSymbol);
        assertEquals(expectedRightSymbol, escapeSymbol.getRightSymbol(),
                "The right symbol should be '" + expectedRightSymbol + "'");
    }
}

==> apache-seata-2.5.0-incubating-src.tar.gz: apache-seata-2.5.0-incubating-src/sqlparser/seata-sqlparser-core/src/test/java/org/apache/seata/sqlparser/EscapeSymbolTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.sqlparser;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class EscapeSymbolTest {

    @Test
    public void testGetLeftSymbol() {
        char expectedLeftSymbol = '"';
        EscapeSymbol escapeSymbol = new EscapeSymbol(expectedLeftSymbol, '"');
        assertEquals(
                expectedLeftSymbol,
                escapeSymbol.getLeftSymbol(),
                "The left symbol should be '" + expectedLeftSymbol + "'");
    }

    @Test
    public void testGetRightSymbol() {
        char expectedRightSymbol = '"';
        EscapeSymbol escapeSymbol = new EscapeSymbol('"', expectedRightSymbol);
        assertEquals(
                expectedRightSymbol,
                escapeSymbol.getRightSymbol(),
                "The right symbol should be '" + expectedRightSymbol + "'");
    }
}
